@@ -19,11 +19,12 @@ sub exec_check_perl4jmx {
     push @args,("--url",$url);
     push @args,("--target",$target) if $target;
     push @args,("--target-user",$target_user,"--target-password",$target_password) if $target_user;
-#    push @args,("--verbose");
+    #push @args,"--legacy-escape";
+    #push @args,("--verbose");
    
     my $cmd = "perl $FindBin::Bin/../../scripts/check_jmx4perl "
-          .join(" ",map { '"' . $_ . '"' } @args); 
-#    print $cmd,"\n";
+          .join(" ",map { '"' . $_ . '"' } @args);  
+    #print $cmd,"\n";
     open (F,"$cmd 2>&1 |") 
       || die "Cannot open check_jmx4perl: $!";
     my $content = join "",<F>;
@@ -41,9 +42,9 @@ sub exec_check_perl4jmx {
 
 sub reset_history {
     my $jmx = shift;
-    my ($mbean,$operation) = $jmx->resolve_alias(JMX4PERL_HISTORY_RESET);
+    my ($mbean,$operation) = $jmx->resolve_alias(JMX4PERL_HISTORY_RESET);   
     my $req = new JMX::Jmx4Perl::Request(EXEC,$mbean,$operation,{target => undef});
-    $jmx->request($req);
+    my $resp = $jmx->request($req);
 }
 
 1;
